# Helpers for Testing Snowflake Python Scripts

Python can help to create amazing python scripts.

Overtime you can come up with a very large collection of scripts.

This library provides some simple helper functions to make testing those scripts even easier.


